@@ -1,4 +1,4 @@
-__version__         = '0.4.8'
+__version__         = '0.4.9'
 __author__          = "Dave Martorana (http://davemartorana.com), Richard Cooper (http://frozenskys.com), Bill Jones (oraclebill), Dmitry Golomidov (deeGraYve)"
 __date__            = '2010-April-14'
 __url__             = 'http://postmarkapp.com'
@@ -39,18 +39,9 @@ except ImportError:
 #
 class PMJSONEncoder(json.JSONEncoder):
     def default(self, o):
-        try:
-            if hasattr(o, '_proxy____str_cast') and isinstance(o._proxy____str_cast, collections.Callable):
-                return o._proxy____str_cast()
-            elif hasattr(o, '_proxy____text_cast') and isinstance(o._proxy____text_cast, collections.Callable):
-                return o._proxy____text_cast()
-            elif hasattr(o, '_proxy____unicode_cast'):
-                return str(o)
-        except:
-            pass
-
+        if hasattr(o, '_proxy____unicode_cast'):
+            return unicode(o)
         return super(PMJSONEncoder, self).default(o)
-
 #
 #
 __POSTMARK_URL__ = 'https://api.postmarkapp.com/'
